@@ -690,11 +690,18 @@ calc_term(int t[MP_SIZE])
 void
 calc_shift(int s[MP_SIZE], int t[MP_SIZE], int times)
 {
-    if (times >= 0)
-        mpmuli(s, times*2, t);
+    int i, multiplier = 1;
+    
+    if (times >= 0) {
+        for (i = 0; i < times; i++)
+            multiplier *= 2;
+        mpmuli(s, multiplier, t);
+    }
     else {
         int temp[MP_SIZE];
-        mpdivi(s, -times*2, temp);
+        for (i = 0; i < -times; i++)
+            multiplier *= 2;
+        mpdivi(s, multiplier, temp);
         mpcmim(temp, t);
     }
 }
